package jp.co.intra_mart.system.workflow.batch;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Properties;

import jp.co.intra_mart.common.platform.log.Logger;
import jp.co.intra_mart.foundation.service.provider.batch.ProcedureComponent;
import jp.co.intra_mart.foundation.workflow.exception.WorkflowException;
import jp.co.intra_mart.foundation.workflow.plugin.stamp.application.general.ArcMatterStampList;
import jp.co.intra_mart.foundation.workflow.plugin.stamp.application.general.condition.StampListSearchCondition;
import jp.co.intra_mart.foundation.workflow.plugin.stamp.application.model.StampDataModel;
import jp.co.intra_mart.foundation.workflow.plugin.stamp.application.model.column.StampDataType;
import jp.co.intra_mart.foundation.workflow.plugin.stamp.application.process.StampProcessManager;
import jp.co.intra_mart.foundation.workflow.util.WorkflowParameterManager;
import jp.co.intra_mart.system.workflow.engine.database.SelectDao4Engine;
import jp.co.intra_mart.system.workflow.engine.database.UpdateDao4Engine;
import jp.co.intra_mart.system.workflow.engine.database.WorkflowDAOBase;
import jp.co.intra_mart.system.workflow.engine.database.WorkflowDAOException;
import jp.co.intra_mart.system.workflow.engine.database.dialect.DefaultDialect;
import jp.co.intra_mart.system.workflow.engine.database.dialect.DialectFactory;
import jp.co.intra_mart.system.workflow.engine.database.model.ArcMatterDataModel;
import jp.co.intra_mart.system.workflow.engine.database.transaction.WorkflowTransactionManager;
import jp.co.intra_mart.system.workflow.engine.tool.EngineArchiveUtil.Name;
import jp.co.intra_mart.system.workflow.util.WorkflowUtil;

/**
 * ߋČeڍsob`
 * 
 * @author INTRAMART
 * @version 1.0.0
 * @since 1.0.0
 */
public class ArchiveStampRecoveryBatch implements ProcedureComponent {

    /**
     * pDAO<BR>
     * eA[JCue[u𐶐܂B
     */
    private static class CreateDao4ArcStamp extends WorkflowDAOBase {

        /**
         * RXgN^
         * 
         * @param loginGroupId OCO[vID
         */
        public CreateDao4ArcStamp(final String loginGroupId) {
            super(loginGroupId);
        }

        /**
         * \̔NƐ\̔NقȂߋČ̔z擾܂B
         * 
         * @param archiveMonth A[JCuNiyyyyMMj
         * @return ߋČ̔z
         * @throws WorkflowDAOException f[^x[XsۂɔO
         */
        public ArcMatterDataModel[] getArchiveMatter(final String archiveMonth)
                throws WorkflowDAOException {

            final StringBuilder builder = new StringBuilder();
            builder.append(super.getSQLString("select.arc.matter"));
            builder.append(SPACE);
            builder.append(super.getSQLString("from.archive.matter"));
            builder.append(SPACE);
            builder.append("WHERE apply_date < ? OR apply_date >= ? ");
            builder.append(SPACE);
            builder.append("ORDER BY apply_date, system_matter_id");

            final Calendar cal = Calendar.getInstance();
            cal.set(Integer.parseInt(archiveMonth.substring(0, 4)),
                    Integer.parseInt(archiveMonth.substring(4)), 1, 0, 0, 0);
            cal.set(Calendar.MILLISECOND, 0);

            final long endDate = cal.getTimeInMillis();
            cal.add(Calendar.MONTH, -1);
            final long startDate = cal.getTimeInMillis();

            final String sql = builder.toString().replace(
                    "%%%ARCHIVE_MONTH%%%", archiveMonth);

            // NGsB
            Connection conn = null;
            PreparedStatement stmt = null;
            ResultSet resultSet = null;
            int index = 0;

            try {
                // Xe[ggIuWFNg𐶐
                conn = super.getConnection();
                stmt = conn.prepareStatement(sql.toString());
                stmt.setDate(++index, new java.sql.Date(startDate));
                stmt.setDate(++index, new java.sql.Date(endDate));

                // NGsČʃZbgԋp
                resultSet = stmt.executeQuery();

                // ԋpׂ̃}bsOsB
                return super.createResultObject(resultSet,
                        ArcMatterDataModel.class, false);

            } catch (final SQLException e) {
                // O}bsO
                throw new WorkflowDAOException("IMW.SRV.ERR.0341", e);
            } finally {

                super.closeResultSet(resultSet);

                // Xe[ggN[YB
                super.closeStatement(stmt);

                // RlNVN[YB
                super.closeConnection(conn);

            }
        }

        /**
         * ߋČ֘Ae[uiimw_ayyyymm_matterj擾B
         * 
         * @param tableNamePrefix e[ȗOu
         * @return List<String> e[ũXg
         * @throws WorkflowDAOException f[^x[XsۂɔO
         */
        public List<String> getArchiveTableNames(final String tableNamePrefix)
                throws WorkflowDAOException {

            final StringBuilder sql = new StringBuilder();
            sql.append(super.getSQLString("select.archive.table"));
            sql.append(SPACE);
            sql.append(DialectFactory.getDialect(super.getDbType())
                    .getPrefixLikeSearchStr());

            switch (super.getDbType()) {
                case POSTGRESQL:
                    sql.append(" AND tablename ");
                    break;
                case ORACLE:
                    sql.append(" AND LOWER(table_name) ");
                    break;
                case DB2:
                    sql.append(" AND LOWER(tabname) ");
                    break;
                case SQLSERVER:
                    sql.append(" AND name ");
                    break;
                default:
            }

            sql.append(getSuffixLikeSearchStr());
            sql.append(" ORDER BY table_name");

            // NGsB
            Connection conn = null;
            PreparedStatement stmt = null;
            ResultSet resultSet = null;
            final int index = 1;

            try {

                // Xe[ggIuWFNg𐶐
                conn = super.getConnection();
                stmt = conn.prepareStatement(sql.toString());
                stmt.setString(index, super.getEscapedValue(tableNamePrefix));
                stmt.setString(index + 1,
                        super.getEscapedValue(ARC_MATTER_TABLE_NAME_POSTFIX));

                // NGsČʃZbgԋp
                resultSet = stmt.executeQuery();

                // ԋpׂ̃}bsOsB
                final List<String> resultList = new ArrayList<String>();

                while (resultSet.next()) {
                    resultList.add(resultSet.getString("table_name")
                            .toLowerCase());
                }

                return resultList;

            } catch (final SQLException e) {
                // O}bsO
                throw new WorkflowDAOException("IMW.SRV.ERR.0339", e);

            } finally {

                super.closeResultSet(resultSet);

                // Xe[ggN[YB
                super.closeStatement(stmt);

                // RlNVN[YB
                super.closeConnection(conn);
            }
        }

        /**
         * LIKE vNG擾B
         * 
         * @return LIKE vpNG
         * @throws WorkflowDAOException f[^x[XsۂɔO
         */
        public String getSuffixLikeSearchStr() throws WorkflowDAOException {

            switch (super.getDbType()) {
                case SQLSERVER:
                    return "LIKE '%' + ? ESCAPE '" + DefaultDialect.SQL_ESCAPE
                            + "'";
                default:
                    return "LIKE '%' || ? ESCAPE '" + DefaultDialect.SQL_ESCAPE
                            + "'";
            }
        }

        /**
         * epߋČe[u𐶐܂B
         * 
         * @param tableName e[u
         * @throws WorkflowDAOException f[^x[XsۂɔO
         */
        void createArcStampTable(final String tableName)
                throws WorkflowDAOException {

            String sql = super.getSQLString("create.arc.stamp.data");

            sql = sql.replace("%%%TABLE_NAME%%%", tableName);

            // NGsB
            Connection conn = null;
            PreparedStatement stmt = null;

            try {

                // Xe[ggIuWFNg𐶐
                conn = super.getConnection();
                stmt = conn.prepareStatement(sql);

                // NGsČʃZbgԋp
                stmt.executeUpdate();

            } catch (final SQLException e) {
                // O}bsO
                throw new WorkflowDAOException("IMW.STAMP.SRV.ERR.2010", e,
                        tableName);
            } finally {

                // Xe[ggN[YB
                super.closeStatement(stmt);

                // RlNVN[YB
                super.closeConnection(conn);
            }
        }
    }

    /**
     * ߋČee[ǔ㕔
     */
    private static final String ARC_STAMP_TABLE_NAME_POSTFIX = "_matter_task_stamp";

    /**
     * ߋČf[^e[ǔ㕔
     */
    private static final String ARC_MATTER_TABLE_NAME_POSTFIX = "_matter";

    /**
     * A[JCuNtH[}bg("yyyyMM")
     */
    private static final String ARCHIVE_MONTH_FORMAT = "yyyyMM";

    /**
     * ob`p[^L[FOrItO
     */
    private static final String ERROR_HANDLING_BREAK_FLAG = "errorHandlingBreakFlag";

    /**
     * K\FN(yyyyMM)
     */
    private static final String REGEX_ARCHIVE_MONTH = "^[1-9][\\d]{3}(0[1-9]|1[0-2])$";

    /**
     * ob`p[^L[FΏۊԊJnN
     */
    private static final String TARGET_ARCHIVE_MONTH_START = "targetArchiveMonthStart";

    /**
     * ob`p[^L[:ΏۊԏIN
     */
    private static final String TARGET_ARCHIVE_MONTH_END = "targetArchiveMonthEnd";

    /**
     * Logger
     */
    private static Logger logger = Logger
            .getLogger(ArchiveStampRecoveryBatch.class);

    /**
     * ݃e[uXg
     */
    private final List<String> tablesNameList = new ArrayList<String>();

    /**
     * tO
     */
    private boolean successFlag = true;

    /**
     * ߋČeڍssB
     * 
     * @param arg0 ob`N
     * @throws RuntimeException sO
     * @throws Error O
     */
    @Override
    public void execute(final Properties arg0) throws RuntimeException, Error {

        final String loginGroupId = arg0.getProperty("group");
        String targetArchiveMonthStart;
        String targetArchiveMonthEnd;
        final String breakFlagStr;

        try {
            // ݒt@Cǂݍ
            final WorkflowParameterManager parameter = new WorkflowParameterManager(
                    loginGroupId);

            // ݒt@CΏۊԊJnN擾
            targetArchiveMonthStart = parameter
                    .getParameter(TARGET_ARCHIVE_MONTH_START);

            // ݒt@CΏۊԏIN擾
            targetArchiveMonthEnd = parameter
                    .getParameter(TARGET_ARCHIVE_MONTH_END);

            // ݒt@COrItO擾
            breakFlagStr = parameter.getParameter(ERROR_HANDLING_BREAK_FLAG);

        } catch (final Exception e) {
            logger.error(WorkflowUtil
                    .getMessage("E.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10008"));
            return;
        }

        // sAsJEg
        long processedCount = 0L;
        long errorCount = 0L;

        try {
            // ΏۊԊJnNݒ肳ĂāAyyyymm̌`ɏ]ĂȂꍇ̗O
            if (!WorkflowUtil.isNull(targetArchiveMonthStart)
                    && !targetArchiveMonthStart.matches(REGEX_ARCHIVE_MONTH)) {

                logger.error(WorkflowUtil.getMessage(
                        "E.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10001",
                        targetArchiveMonthStart));

                return;
            }

            // ΏۊԏINݒ肳ĂāAyyyymm̌`ɏ]ĂȂꍇ̗O
            if (!WorkflowUtil.isNull(targetArchiveMonthEnd)
                    && !targetArchiveMonthEnd.matches(REGEX_ARCHIVE_MONTH)) {

                logger.error(WorkflowUtil.getMessage(
                        "E.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10002",
                        targetArchiveMonthEnd));

                return;
            }

            // OBbreakFlagɋ󗓂AfalseȊO̒l͂ĂꍇAtrueƂď
            final boolean breakFlag = WorkflowUtil.isNull(breakFlagStr) ? true
                    : ("false".equals(breakFlagStr.toLowerCase()) ? false
                            : true);

            logger.info(WorkflowUtil.getMessage(
                    "I.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10001",
                    targetArchiveMonthStart, targetArchiveMonthEnd,
                    String.valueOf(breakFlag)));

            final CreateDao4ArcStamp selectDao = new CreateDao4ArcStamp(
                    loginGroupId);
            final List<String> tableNameList = selectDao
                    .getArchiveTableNames(Name.IMW_A.toString().toLowerCase());
            if (tableNameList.size() < 1) {

                logger.warn(WorkflowUtil
                        .getMessage("W.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10001"));

                return;
            }

            // ΏۊԊJnNFݒlȂꍇAA[JCue[uXg擾A0ԖڂɎ[ꂽe[u̔NΏۊԊJnNƂĐݒ肷
            if (WorkflowUtil.isNull(targetArchiveMonthStart)) {
                targetArchiveMonthStart = getArchiveYearMonth(tableNameList
                        .get(0));
            }
            final Date startDate = WorkflowUtil.getTimeFromStr(
                    targetArchiveMonthStart, ARCHIVE_MONTH_FORMAT);

            // ΏۊԏINFݒlȂꍇAA[JCue[uXg擾AŌɎ[ꂽe[u̔NΏۊԏINƂĐݒ肷
            if (WorkflowUtil.isNull(targetArchiveMonthEnd)) {
                targetArchiveMonthEnd = getArchiveYearMonth(tableNameList
                        .get(tableNameList.size() - 1));
            }
            final Date endDate = WorkflowUtil.getTimeFromStr(
                    targetArchiveMonthEnd, ARCHIVE_MONTH_FORMAT);

            if (!startDate.equals(endDate) && startDate.after(endDate)) {

                logger.error(WorkflowUtil.getMessage(
                        "E.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10003",
                        targetArchiveMonthStart, targetArchiveMonthEnd));

                return;
            }

            // w肵JnN̉ߋČe[uXg̃CfbNX擾
            int startArcMonthIndex = tableNameList
                    .indexOf(getArcMatterTableName(targetArchiveMonthStart));
            if (startArcMonthIndex < 0) {
                startArcMonthIndex = getTargetTableNameIndex(tableNameList, 1,
                        startDate, endDate);
                if (startArcMonthIndex < 0) {

                    logger.info(WorkflowUtil.getMessage(
                            "I.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10005",
                            targetArchiveMonthStart,targetArchiveMonthEnd));

                    return;
                }
            }
            // w肵IN̉ߋČe[uXg̃CfbNX擾
            int endArcMonthIndex = tableNameList
                    .indexOf(getArcMatterTableName(targetArchiveMonthEnd));
            if (endArcMonthIndex < 0) {
                endArcMonthIndex = getTargetTableNameIndex(tableNameList, -1,
                        endDate, startDate);
                if (endArcMonthIndex < 0) {

                    logger.info(WorkflowUtil.getMessage(
                            "I.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10005",
                            targetArchiveMonthStart,targetArchiveMonthEnd));

                    return;
                }
            }

            for (int i = startArcMonthIndex; i <= endArcMonthIndex; i++) {
                final String tableName = tableNameList.get(i);
                final String archiveMonth = getArchiveYearMonth(tableName);
                final Map<String, Long> result = trasnferArchiveMatterStampData(
                        archiveMonth, breakFlag, loginGroupId);
                processedCount += result.get("processedCount").longValue();
                errorCount += result.get("errorCount").longValue();

                if (!this.successFlag) {
                    // tOfalsȅꍇ͏𒆒fB
                    break;
                }
            }

        } catch (final Exception e) {
            // A[JCuN̈ڍsُI

            logger.error(WorkflowUtil.getMessage(
                    "E.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10005",
                    String.valueOf(processedCount),
                    String.valueOf(processedCount + errorCount),
                    String.valueOf(errorCount)), e);

            return;
        }

        // 
        if (this.successFlag) {

            logger.info(WorkflowUtil.getMessage(
                    "I.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10004",
                    String.valueOf(processedCount + errorCount),
                    String.valueOf(processedCount), String.valueOf(errorCount))

            );

        } else {
            // s

            logger.error(WorkflowUtil.getMessage(
                    "E.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10007",
                    String.valueOf(processedCount + errorCount),
                    String.valueOf(processedCount), String.valueOf(errorCount)));
        }
    }

    /**
     * A[JCue[u݃`FbN
     * 
     * @param tableName e[u
     * @param loginGroupId OCO[vID
     * @return boolean e[u݂ꍇ trueAȊȌꍇ falseԂ܂B
     * @throws WorkflowDAOException f[^x[XsۂɔO
     */
    private boolean checkTable(final String tableName, final String loginGroupId)
            throws WorkflowDAOException {
        if (this.tablesNameList.contains(tableName)) {
            return true;
        }
        final SelectDao4Engine selectDao = new SelectDao4Engine(loginGroupId);
        final boolean checkTable = selectDao.isArchiveMatterTable(tableName);
        if (checkTable) {
            this.tablesNameList.add(tableName);
        }
        return checkTable;
    }

    /**
     * debugxœ삵ĂۂɁAdebugOo͂
     * 
     * @param messageId bZ[WID
     * @param messageBindParam bZ[Wp̒l
     * 
     */
    private void doDebugLog(final String messageId,
            final String... messageBindParam) {

        if (logger.isDebugEnabled()) {
            final String message = WorkflowUtil.getMessage(messageId,
                    messageBindParam);
            logger.debug(message);
        }
    }

    /**
     * e[uA[JCuN擾܂B<br/>
     * <br/>
     * 
     * @param tableName e[u
     * @return A[JCuN
     */
    private String getArchiveYearMonth(final String tableName) {
        return tableName.substring(5, 11);
    }

    /**
     * A[JCue[u
     * 
     * @param archiveMonth(yyyyMM) A[JCuN
     * @return String ߋČe[u(imw_ayyyyMM_matter)
     */
    private String getArcMatterTableName(final String archiveMonth) {
        return Name.IMW_A.toString().toLowerCase() + archiveMonth
                + ARC_MATTER_TABLE_NAME_POSTFIX;
    }

    /**
     * A[JCuee[u
     * 
     * @param archiveMonth A[JCuN
     * @return String ߋČee[u(imw_ayyyyMM_matter_task_stamp)
     */
    private String getArcStampTableName(final String archiveMonth) {
        return Name.IMW_A.toString().toLowerCase() + archiveMonth
                + ARC_STAMP_TABLE_NAME_POSTFIX;
    }

    /**
     * e[uXgY擾
     * 
     * @param tableNameList e[ũXg
     * @param amount N(1,-1)
     * @param startDate JnN
     * @param endDate IN
     * @return e[uXg̊Y
     */
    private int getTargetTableNameIndex(final List<String> tableNameList,
            final int amount, final Date startDate, final Date endDate) {
        int targetIndex = -1;
        final Calendar cal = Calendar.getInstance();
        cal.setTime(startDate);
        while (targetIndex < 0) {
            cal.add(Calendar.MONTH, amount);
            targetIndex = tableNameList
                    .indexOf(getArcMatterTableName(WorkflowUtil
                            .getCurrentTimeStr(cal.getTime(), "yyyyMM")));
            if ((amount < 0 && cal.getTime().before(endDate))
                    || (amount > 0 && cal.getTime().after(endDate))) {
                return -1;
            }
        }
        return targetIndex;
    }

    /**
     * eڍs \Ɛ\̔NႤČ肵AYe\N̈ee[uɕAڍs폜܂B
     * 
     * @param archiveMonth \N()
     * @param breakFlag ItOitrue:OꍇAIBfalse:OꍇA𑱍sBj
     * @param loginGroupId OCO[vID
     * @return Map<String, Long> 
     * @throws WorkflowException [Nt[sۂɔO
     */
    private Map<String, Long> trasnferArchiveMatterStampData(
            final String archiveMonth, final boolean breakFlag,
            final String loginGroupId) throws WorkflowException {
        long processedCount = 0L;
        long errorCount = 0L;
        final Map<String, Long> resultMap = new HashMap<String, Long>();

        logger.info(WorkflowUtil.getMessage(
                "I.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10002", archiveMonth));

        final WorkflowTransactionManager transactionManager = new WorkflowTransactionManager();

        final CreateDao4ArcStamp create = new CreateDao4ArcStamp(loginGroupId);
        final ArcMatterDataModel[] arcModels = create
                .getArchiveMatter(archiveMonth);
        for (final ArcMatterDataModel arcModel : arcModels) {
            // ߋČ̐\N擾
            final String applyDateMonth = WorkflowUtil.getCurrentTimeStr(
                    arcModel.getApplyDate(), ARCHIVE_MONTH_FORMAT);

            // \̔Nō쐬ꂽߋČee[u݃`FbN
            final String applyDateTableName = getArcStampTableName(applyDateMonth);
            if (!this.checkTable(applyDateTableName, loginGroupId)) {
                continue;
            }

            // ߋČ̃VXeČID擾
            final String systemMatterId = arcModel.getSystemMatterId();

            // \̔Nō쐬ꂽߋČee[u݃`FbNYČ̈e̎擾
            final StampListSearchCondition<StampDataType> cond = new StampListSearchCondition<StampDataType>();
            cond.addOrder(StampDataType.PROCESS_DATE, true);

            final ArcMatterStampList stampList = new ArcMatterStampList(
                    loginGroupId, applyDateMonth);
            final int stampListCount = stampList.getStampListCount(
                    systemMatterId, cond);
            if (stampListCount < 1) {
                continue;
            }

            // \̔Nō쐬ꂽߋČee[u݃`FbN
            final String toStampTable = getArcStampTableName(archiveMonth);
            if (!this.checkTable(toStampTable, loginGroupId)) {
                // \̔N̉ߋČee[u쐬
                create.createArcStampTable(toStampTable);
                this.tablesNameList.add(toStampTable);
            }

            doDebugLog("D.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10001",
                    applyDateTableName, toStampTable, systemMatterId);

            try {
                // ڍsΏۈeɑ΂ďs
                // DBgUNVJn
                transactionManager.begin();

                doDebugLog("D.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10002",
                        systemMatterId);

                // e\Ne[uփRs[
                final UpdateDao4Engine updateDao = new UpdateDao4Engine(
                        loginGroupId);
                updateDao.copyTable(toStampTable, applyDateTableName,
                        systemMatterId);

                doDebugLog("D.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10003");

                // Rs[ς݃f[^폜
                final StampDataModel model = new StampDataModel();
                model.setSystemMatterId(systemMatterId);

                final StampProcessManager stampManager = new StampProcessManager(
                        loginGroupId);
                stampManager.deleteArcMatterStampData(applyDateMonth, model);

                doDebugLog("D.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10004");

                // DBgUNV R~bg
                transactionManager.commit();
                processedCount++;

                doDebugLog("D.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10005",
                        systemMatterId);

            } catch (final Exception e) {

                logger.error(WorkflowUtil.getMessage(
                        "E.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10004",
                        systemMatterId), e);

                // sJEg
                errorCount++;

                try {
                    // DBgUNV [obN
                    transactionManager.rollback();
                } catch (final Exception we) {
                    // [obNɎsɁAȂ[obN悤Ƃ̌ǉ
                    we.initCause(e);

                    logger.error(WorkflowUtil.getMessage(
                            "E.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10006",
                            systemMatterId), we);

                    // [obNsȂ̂ŋI
                    this.successFlag = false;
                    resultMap.put("processedCount",
                            Long.valueOf(processedCount));
                    resultMap.put("errorCount", Long.valueOf(errorCount));
                    return resultMap;
                }

                if (breakFlag) {

                    logger.info(WorkflowUtil.getMessage(
                            "I.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10003",
                            archiveMonth,
                            String.valueOf(processedCount + errorCount),
                            String.valueOf(processedCount),
                            String.valueOf(errorCount)));

                    // tOfalseɏ
                    this.successFlag = false;
                    resultMap.put("processedCount",
                            Long.valueOf(processedCount));
                    resultMap.put("errorCount", Long.valueOf(errorCount));
                    return resultMap;
                }
            }
        }

        logger.info(WorkflowUtil.getMessage(
                "I.IMW.JOBSCHEDULER.ARCHIVESTAMPRECOVERY.10003", archiveMonth,
                String.valueOf(processedCount + errorCount),
                String.valueOf(processedCount), String.valueOf(errorCount)));

        // ԋpݒ
        resultMap.put("processedCount", processedCount);
        resultMap.put("errorCount", errorCount);
        return resultMap;
    }
}
